==> bigloo1.3b.tar.gz: bigloo1.3/comptime1.3/Tools/date.c <==
/*---------------------------------------------------------------------*/
/*    Copyright (c) 1993 by Manuel Serrano. All rights reserved.       */
/*                                                                     */
/*                                     ,--^,                           */
/*                               _ ___/ /|/                            */
/*                           ,;'( )__, ) '                             */
/*                          ;;  //   L__.                              */
/*                          '   \    /  '                              */
/*                               ^   ^                                 */
/*                                                                     */
/*                                                                     */
/*    This program is distributed in the hope that it will be useful.  */
/*    Use and copying of this software and preparation of derivative   */
/*    works based upon this software are permitted, so long as the     */
/*    following conditions are met:                                    */
/*           o credit to the authors is acknowledged following         */
/*             current academic behaviour                              */
/*           o no fees or compensation are charged for use, copies,    */
/*             or access to this software                              */
/*           o this copyright notice is included intact.               */
/*      This software is made available AS IS, and no warranty is made */
/*      about the software or its performance.                         */
/*                                                                     */
/*      Bug descriptions, use reports, comments or suggestions are     */
/*      welcome Send them to                                           */
/*        <Manuel.Serrano@inria.fr>                                    */
/*        Manuel Serrano                                               */
/*        INRIA -- Rocquencourt                                        */
/*        Domaine de Voluceau, BP 105                                  */
/*        78153 Le Chesnay Cedex                                       */
/*        France                                                       */
/*---------------------------------------------------------------------*/


/*=====================================================================*/
/*   Tools/date.c                                                      */
/*   Bigloo (v1.3)                                                     */
/*   Manuel Serrano (c)             Mon Jul 5 15:52:35 MET DST 1993    */
/*=====================================================================*/
#include <bigloo.h>

static obj_t REQUIRE_INITIALISATION__TOOLS_DATE_129 = BUNSPEC;
static obj_t PROCEDURE_2_TOOLS_DATE_12 = BUNSPEC;
extern obj_t make_fx_procedure();
static obj_t PROCEDURE_1_TOOLS_DATE_41 = BUNSPEC;
obj_t BIGLOO_DATE_ENV_TOOLS_DATE_107 = BUNSPEC;
extern obj_t __BIGLOO_DATE_TOOLS_DATE_92();
extern obj_t __TOOLS_DATE_INITIALISATION_TOOLS_DATE_64();
extern obj_t BIGLOO_DATE_TOOLS_DATE_95();
static obj_t __MON_JUL_0_TOOLS_DATE_170 = BUNSPEC;
extern obj_t TOOLS_DATE_INITIALISATION_TOOLS_DATE_39();
obj_t TOOLS_DATE_INITIALISATION_ENV_TOOLS_DATE_115 = BUNSPEC;


obj_t
#if defined( __STDC__ )
BIGLOO_DATE_TOOLS_DATE_95()
#else
BIGLOO_DATE_TOOLS_DATE_95()
#endif
{
_BIGLOO_DATE_TOOLS_DATE_95:

return __MON_JUL_0_TOOLS_DATE_170;
}

obj_t
#if defined( __STDC__ )
__BIGLOO_DATE_TOOLS_DATE_92(obj_t ENV_1_214)
#else
__BIGLOO_DATE_TOOLS_DATE_92( ENV_1_214 )
obj_t ENV_1_214;
#endif
{
___BIGLOO_DATE_TOOLS_DATE_92:

return BIGLOO_DATE_TOOLS_DATE_95();
}

obj_t
#if defined( __STDC__ )
TOOLS_DATE_INITIALISATION_TOOLS_DATE_39()
#else
TOOLS_DATE_INITIALISATION_TOOLS_DATE_39()
#endif
{
_TOOLS_DATE_INITIALISATION_TOOLS_DATE_39:

if( BBOOL_TO_CBOOL( REQUIRE_INITIALISATION__TOOLS_DATE_129 ))
{
REQUIRE_INITIALISATION__TOOLS_DATE_129=BFALSE;
TOOLS_DATE_INITIALISATION_TOOLS_DATE_39();
__MON_JUL_0_TOOLS_DATE_170=CSTRING_TO_BSTRING( " Mon Jul 5 15:52:35 MET DST 1993 " );
PROCEDURE_2_TOOLS_DATE_12=make_fx_procedure( __TOOLS_DATE_INITIALISATION_TOOLS_DATE_64, 0, 0 );
PROCEDURE_1_TOOLS_DATE_41=make_fx_procedure( __BIGLOO_DATE_TOOLS_DATE_92, 0, 0 );
{
BIGLOO_DATE_ENV_TOOLS_DATE_107=PROCEDURE_1_TOOLS_DATE_41;
TOOLS_DATE_INITIALISATION_ENV_TOOLS_DATE_115=PROCEDURE_2_TOOLS_DATE_12;
return BINT( 0 );
}
}else
return BUNSPEC;
}

obj_t
#if defined( __STDC__ )
__TOOLS_DATE_INITIALISATION_TOOLS_DATE_64(obj_t ENV_0_18)
#else
__TOOLS_DATE_INITIALISATION_TOOLS_DATE_64( ENV_0_18 )
obj_t ENV_0_18;
#endif
{
___TOOLS_DATE_INITIALISATION_TOOLS_DATE_64:

return TOOLS_DATE_INITIALISATION_TOOLS_DATE_39();
}

==> bigloo_1.8b.orig.tar.gz: bigloo-1.8b.orig/comptime1.8/Tools/date.c <==
/*---------------------------------------------------------------------*/
/*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
/*                                                                     */
/*                                     ,--^,                           */
/*                               _ ___/ /|/                            */
/*                           ,;'( )__, ) '                             */
/*                          ;;  //   L__.                              */
/*                          '   \    /  '                              */
/*                               ^   ^                                 */
/*                                                                     */
/*                                                                     */
/*    This program is distributed in the hope that it will be useful.  */
/*    Use and copying of this software and preparation of derivative   */
/*    works based upon this software are permitted, so long as the     */
/*    following conditions are met:                                    */
/*           o credit to the authors is acknowledged following         */
/*             current academic behaviour                              */
/*           o no fees or compensation are charged for use, copies,    */
/*             or access to this software                              */
/*           o this copyright notice is included intact.               */
/*      This software is made available AS IS, and no warranty is made */
/*      about the software or its performance.                         */
/*                                                                     */
/*      Bug descriptions, use reports, comments or suggestions are     */
/*      welcome Send them to                                           */
/*        <Manuel.Serrano@inria.fr>                                    */
/*        Manuel Serrano                                               */
/*        INRIA -- Rocquencourt                                        */
/*        Domaine de Voluceau, BP 105                                  */
/*        78153 Le Chesnay Cedex                                       */
/*        France                                                       */
/*---------------------------------------------------------------------*/


/*=====================================================================*/
/*   Tools/date.scm                                                    */
/*   Bigloo (v1.8)                                                     */
/*   Manuel Serrano (c)       Fri Apr 12 15:32:40 PDT 1996             */
/*=====================================================================*/
#define THE_GC BOEHM_GC
#include <bigloo.h>

/* The C generated type (for typed structures) */
static obj_t *__cnst;
extern obj_t _bigloo_date_tools_date_199( obj_t );
static obj_t tvectors_declarations__tools_date_11();
DEFINE_STRING( string1004_tools_date, aux1105, " Thu Apr 11 10:48:22 PDT 1996 ", 30 );
extern obj_t initialization_tools_date();
extern obj_t bigloo_date_tools_date_6();
static obj_t initialize_constants__tools_date_219();
static obj_t initialize_imported_modules__tools_date_194();
static obj_t require_initialization__tools_date_190 = BUNSPEC;

DEFINE_EXPORT_PROCEDURE( bigloo_date_env_tools_date_38, aux1106, _bigloo_date_tools_date_199, 0L, 0 );

obj_t initialization_tools_date()
{if(CBOOL(require_initialization__tools_date_190)){require_initialization__tools_date_190 = BFALSE;
initialize_imported_modules__tools_date_194();
tvectors_declarations__tools_date_11();
initialize_constants__tools_date_219();
require_initialization__tools_date_190 = BFALSE;
return BUNSPEC;
} else {return BUNSPEC;
}}

obj_t initialize_imported_modules__tools_date_194()
{return BUNSPEC;
}

obj_t initialize_constants__tools_date_219()
{return BUNSPEC;
}

obj_t tvectors_declarations__tools_date_11()
{return BUNSPEC;
}

obj_t bigloo_date_tools_date_6()
{return string1004_tools_date;
}

obj_t _bigloo_date_tools_date_199(obj_t env_1)
{return bigloo_date_tools_date_6();
}
